@@ -1,13 +1,14 @@
-from lxml import etree
 from FreeTAKServer.controllers.configuration.LoggingConstants import LoggingConstants
 from FreeTAKServer.controllers.CreateLoggerController import CreateLoggerController
 from FreeTAKServer.model.FTSModel.Event import Event as event
 from FreeTAKServer.controllers.configuration.MainConfig import MainConfig
+from abc import ABC
+from FreeTAKServer.controllers.serializers import xml_serializer
 
 loggingConstants = LoggingConstants()
 logger = CreateLoggerController("SendCoTAbstract").getLogger()
 
-class SendCoTAbstractController:
+class SendCoTAbstractController(ABC):
     Event = event
     def __init__(self, object):
         pass
@@ -15,20 +16,28 @@ class SendCoTAbstractController:
     def fill_object(self, object, tempObject, RawCoT, addToDB = MainConfig.SaveCoTToDB):
         try:
             object.modelObject = self.create_model_object(tempObject, RawCoT.xmlString)
+
         except Exception as e:
-            logger.error('there has been an exception in the creation of a model object ' + str(e))
+            if tempObject.type != "other":
+                self.handel_serialization_exception(object, RawCoT)
+                logger.error('an undocumented CoT has been sent returning the error ' + str(e) + ' please post this as an issue on the FTS git so we can document and fix it')
+                return 1
+            else:
+                logger.warning('there has been an exception in the creation of the model object ' + str(e))
+                return -1
+
         try:
             object.xmlString = self.create_xml_string(object.modelObject)
         except Exception as e:
-            logger.error('there has been an exception in the creation of a xmlString ' + str(e))
+            logger.warning('there has been an exception in the creation of a xmlString ' + str(e))
         try:
             if addToDB == True:
                 RawCoT.dbController.create_CoT(object.modelObject)
             else:
                 pass
         except Exception as e:
-            logger.error('there has been an exception in the creation of a database instance of this object ' + str(e))
-
+            logger.warning('there has been an exception in the creation of a database instance of this object ' + str(e))
+            raise Exception(e)
         self.setObject(object)
 
     def create_model_object(self, tempObject, xmlString):
@@ -38,13 +47,8 @@ class SendCoTAbstractController:
         """
         from FreeTAKServer.controllers.XMLCoTController import XMLCoTController
 
-        try:
-            modelInstance = XMLCoTController().serialize_CoT_to_model(tempObject,
-                                                      etree.fromstring(xmlString))
-            return modelInstance
-        except Exception as e:
-            logger.error('there has been an exception in the creation of the model object ' + str(e))
-            return -1
+        modelInstance = xml_serializer.XmlSerializer().from_format_to_fts_object(xmlString, tempObject)
+        return modelInstance
     def create_xml_string(self, modelObject):
         """
         this function calls the model to xml serializer within XMLCoTController
@@ -58,6 +62,17 @@ class SendCoTAbstractController:
             logger.error('there has been an exception in the creation of the xml string ' +str(e))
             return -1
 
+    def handel_serialization_exception(self, object, RawCoT):
+        """
+        this function will handle any exception thrown in the process of serialization of an xml CoT to it's respective model object
+        by processing it as an Other type
+        """
+        from FreeTAKServer.controllers.SpecificCoTControllers.SendOtherController import SendOtherController
+        object = SendOtherController(RawCoT).getObject()
+        object.clientInformation = RawCoT.clientInformation
+        self.setObject(object)
+
+
     def setObject(self, object):
         self.Object = object
 
